Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(569)

Unified Diff: chrome/browser/ui/browser.h

Issue 7831051: content: Move collected cookies constrained window to TabContentsWrapper. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Compile failures for everyone\! Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/automation/testing_automation_provider.cc ('k') | chrome/browser/ui/browser.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/browser.h
diff --git a/chrome/browser/ui/browser.h b/chrome/browser/ui/browser.h
index b131f1279b591703c8b6b5bf2c92a62784ee4974..3f0932fe17f55529e1a02d26456a88f549d54181 100644
--- a/chrome/browser/ui/browser.h
+++ b/chrome/browser/ui/browser.h
@@ -727,8 +727,8 @@ class Browser : public TabHandlerDelegate,
// specified.
GURL GetHomePage() const;
- // Shows the cookies collected in the tab contents.
- void ShowCollectedCookiesDialog(TabContents* tab_contents);
+ // Shows the cookies collected in the tab contents wrapper.
+ void ShowCollectedCookiesDialog(TabContentsWrapper* wrapper);
// Interface implementations ////////////////////////////////////////////////
« no previous file with comments | « chrome/browser/automation/testing_automation_provider.cc ('k') | chrome/browser/ui/browser.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698